@@ -1,8 +1,7 @@
-from typing import Any, List, Tuple
+from typing import Any, Callable, List, Tuple
 
 from uplink import Query, get, response_handler, returns
 
-from bpkio_api.caching import cache_api_results
 from bpkio_api.consumer import BpkioSdkConsumer
 from bpkio_api.helpers.list import get_all_with_pagination
 from bpkio_api.helpers.search import SearchMethod, search_array_with_filters
@@ -37,9 +36,9 @@ class TranscodingProfilesApi(BpkioSdkConsumer):
     # === Helpers ===
 
     # @cache_api_results("list_profiles")
-    def list(self, tenant_id: int = None):
+    def list(self, tenant_id: int = None, progress_hook: Callable[[int, Any, str | None], None] | None = None, **kwargs):
         return get_all_with_pagination(
-            self._get_page, count_fn=self.count, tenant_id=tenant_id
+            self._get_page, count_fn=self.count, tenant_id=tenant_id, progress_hook=progress_hook
         )
 
     def search(
@@ -49,6 +48,7 @@ class TranscodingProfilesApi(BpkioSdkConsumer):
         method: SearchMethod = SearchMethod.STRING_SUB,
         filters: List[Tuple[Any, str | None, SearchMethod | None]] | None = None,
         tenant_id: int = None,
+        progress_hook: Callable[[int, Any, str | None], None] | None = None,
     ) -> List[TranscodingProfile]:
         """Searches the list of transcoding profiles for those matching a particular filter query
 
@@ -74,5 +74,5 @@ class TranscodingProfilesApi(BpkioSdkConsumer):
         if not filters:
             filters = [(value, field, method)]
 
-        profiles = self.list(tenant_id=tenant_id)
+        profiles = self.list(tenant_id=tenant_id, progress_hook=progress_hook)
         return search_array_with_filters(profiles, filters=filters)
